@@ -3,7 +3,7 @@ from wagtail.admin.edit_handlers import StreamFieldPanel, FieldPanel
 from wagtail.core.fields import StreamField
 from wagtail.snippets.blocks import SnippetChooserBlock
 from modelcluster.models import ClusterableModel
-from webspace.cms.blocks.common import ButtonBlock
+from webspace.cms.blocks.common import ButtonBlock, LinkBlock, FormBlock
 
 
 class ANavigation(ClusterableModel):
@@ -11,15 +11,16 @@ class ANavigation(ClusterableModel):
 
     footer = StreamField([
         ('menu', SnippetChooserBlock('cms.Menu', required=False)),
-    ], blank=True)
+    ], blank=True, verbose_name="Footer items")
 
     header_menus = StreamField([
         ('menu', SnippetChooserBlock('cms.Menu', required=False)),
-    ], blank=True)
+        ('link', LinkBlock())
+    ], blank=True, verbose_name="Header items")
 
     header_buttons = StreamField([
         ('button', ButtonBlock())
-    ], blank=True)
+    ], blank=True, verbose_name="Header button")
 
     panels = [
         FieldPanel("help_text"),
